@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2002-2012 Free Software Foundation, Inc.
+# Copyright (C) 2002-2020 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,11 +12,11 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check that Automake warns about user variables being overridden.
 
-. ./defs || Exit 1
+. test-init.sh
 
 # We need (almost) complete control over automake options.
 AUTOMAKE="$am_original_AUTOMAKE -Werror"
@@ -47,7 +47,7 @@ AUTOMAKE_fails --add-missing --gnu
 grep '^Makefile\.am:1:.*CFLAGS' stderr
 grep '^Makefile\.am:2:.*LDFLAGS' stderr
 # No reason to warn about CXXFLAGS since it's not used.
-grep CXXFLAGS stderr && Exit 1
+grep CXXFLAGS stderr && exit 1
 # Don't warn if -Wno-gnu.
 $AUTOMAKE --gnu -Wno-gnu
 
